==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/ca.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Emmagatzemament no vàlid",
    "Unknown error" : "Error desconegut",
    "All files" : "Tots els fitxers",
    "Saved" : "Desat",
    "Home" : "Inici",
    "Close" : "Tanca",
    "Favorites" : "Preferits",
    "Upload cancelled." : "La pujada s'ha cancel·lat.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No es pot pujar {filename} perquè és una carpeta o té 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hi ha prou espai lliure, està carregant {size1} però només pot {size2}",
    "Uploading..." : "Pujant...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Hi ha una pujada en curs. Si abandoneu la pàgina la pujada es cancel·larà.",
    "Actions" : "Accions",
    "Download" : "Baixa",
    "Rename" : "Reanomena",
    "Delete" : "Esborra",
    "Disconnect storage" : "Desonnecta l'emmagatzematge",
    "Unshare" : "Deixa de compartir",
    "Files" : "Fitxers",
    "Details" : "Detalls",
    "Select" : "Selecciona",
    "Pending" : "Pendent",
    "Unable to determine date" : "No s'ha pogut determinar la data",
    "Invalid path" : "El camí no és vàlid",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Modificat",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "No teniu permisos per a pujar o crear els fitxers aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Pujant %n fitxer","Pujant %n fitxers"],
    "New" : "Nou",
    "\"{name}\" is an invalid file name." : "\"{name}\" no es un fitxer vàlid.",
    "File name cannot be empty." : "El nom del fitxer no pot ser buit.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'emmagatzematge de {owner} està ple, els arxius no es poden actualitzar o sincronitzar més!",
    "Your storage is full, files can not be updated or synced anymore!" : "El vostre espai d'emmagatzemament és ple, els fitxers ja no es poden actualitzar o sincronitzar!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Emmagatzematge de {owner} està gairebé ple ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "El vostre espai d'emmagatzemament és gairebé ple ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidències '{filter}'","coincidència '{filter}'"],
    "Favorited" : "Agregat a favorits",
    "Favorite" : "Preferits",
    "Folder" : "Carpeta",
    "New folder" : "Carpeta nova",
    "Upload" : "Puja",
    "An error occurred while trying to update the tags" : "S'ha produït un error en tractar d'actualitzar les etiquetes",
    "A new file or folder has been <strong>created</strong>" : "S'ha <strong>creat</strong> un nou fitxer o una nova carpeta",
    "A file or folder has been <strong>changed</strong>" : "S'ha <strong>canviat</strong> un fitxer o una carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar les notificacions sobre la creació i canvis dels seus <strong>arxius favorits</strong><em>(solament Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "S'ha <strong>elminiat</strong> un fitxer o una carpeta",
    "A file or folder has been <strong>restored</strong>" : "S'ha <strong>restaurat</strong> un fitxer o una carpeta",
    "You created %1$s" : "Has creat %1$s",
    "%2$s created %1$s" : "%2$s ha creat %1$s",
    "%1$s was created in a public folder" : "Es va crear %1$s en una carpeta pública",
    "You changed %1$s" : "Has canviat %1$s",
    "%2$s changed %1$s" : "%2$s ha canviat %1$s",
    "You deleted %1$s" : "Has esborrat %1$s",
    "%2$s deleted %1$s" : "%2$s ha esborrat %1$s",
    "You restored %1$s" : "Has restaurat %1$s",
    "%2$s restored %1$s" : "%2$s ha restaurat %1$s",
    "Upload (max. %s)" : "Pujada (màx. %s)",
    "File handling" : "Gestió de fitxers",
    "Maximum upload size" : "Mida màxima de pujada",
    "max. possible: " : "màxim possible:",
    "Save" : "Desa",
    "Settings" : "Arranjament",
    "WebDAV" : "WebDAV",
    "No files in here" : "No hi ha arxius",
    "Upload some content or sync with your devices!" : "Pugi continguts o sincronitzi els seus dispositius.",
    "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
    "Select all" : "Seleccionar tot",
    "Upload too large" : "La pujada és massa gran",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Els fitxers que esteu intentant pujar excedeixen la mida màxima de pujada del servidor",
    "No favorites" : "No hi ha favorits",
    "Files and folders you mark as favorite will show up here" : "Aquí apareixeran els arxius i carpetes que vostè marqui com favorits",
    "Text file" : "Fitxer de text"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.10.tgz: owncloud/apps/files/l10n/ca.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Emmagatzemament no vàlid",
    "Unknown error" : "Error desconegut",
    "All files" : "Tots els fitxers",
    "Saved" : "Desat",
    "Home" : "Inici",
    "Close" : "Tanca",
    "Favorites" : "Preferits",
    "Upload cancelled." : "La pujada s'ha cancel·lat.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "No es pot pujar {filename} perquè és una carpeta o té 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "No hi ha prou espai lliure, està carregant {size1} però només pot {size2}",
    "Uploading..." : "Pujant...",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Hi ha una pujada en curs. Si abandoneu la pàgina la pujada es cancel·larà.",
    "Actions" : "Accions",
    "Download" : "Baixa",
    "Rename" : "Reanomena",
    "Delete" : "Esborra",
    "Disconnect storage" : "Desonnecta l'emmagatzematge",
    "Unshare" : "Deixa de compartir",
    "Files" : "Fitxers",
    "Details" : "Detalls",
    "Select" : "Selecciona",
    "Pending" : "Pendent",
    "Unable to determine date" : "No s'ha pogut determinar la data",
    "Invalid path" : "El camí no és vàlid",
    "Name" : "Nom",
    "Size" : "Mida",
    "Modified" : "Modificat",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "_%n file_::_%n files_" : ["%n fitxer","%n fitxers"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "You don’t have permission to upload or create files here" : "No teniu permisos per a pujar o crear els fitxers aquí",
    "_Uploading %n file_::_Uploading %n files_" : ["Pujant %n fitxer","Pujant %n fitxers"],
    "New" : "Nou",
    "\"{name}\" is an invalid file name." : "\"{name}\" no es un fitxer vàlid.",
    "File name cannot be empty." : "El nom del fitxer no pot ser buit.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "L'emmagatzematge de {owner} està ple, els arxius no es poden actualitzar o sincronitzar més!",
    "Your storage is full, files can not be updated or synced anymore!" : "El vostre espai d'emmagatzemament és ple, els fitxers ja no es poden actualitzar o sincronitzar!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Emmagatzematge de {owner} està gairebé ple ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "El vostre espai d'emmagatzemament és gairebé ple ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["coincidències '{filter}'","coincidència '{filter}'"],
    "Favorited" : "Agregat a favorits",
    "Favorite" : "Preferits",
    "Folder" : "Carpeta",
    "New folder" : "Carpeta nova",
    "Upload" : "Puja",
    "An error occurred while trying to update the tags" : "S'ha produït un error en tractar d'actualitzar les etiquetes",
    "A new file or folder has been <strong>created</strong>" : "S'ha <strong>creat</strong> un nou fitxer o una nova carpeta",
    "A file or folder has been <strong>changed</strong>" : "S'ha <strong>canviat</strong> un fitxer o una carpeta",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitar les notificacions sobre la creació i canvis dels seus <strong>arxius favorits</strong><em>(solament Stream)</em>",
    "A file or folder has been <strong>deleted</strong>" : "S'ha <strong>elminiat</strong> un fitxer o una carpeta",
    "A file or folder has been <strong>restored</strong>" : "S'ha <strong>restaurat</strong> un fitxer o una carpeta",
    "You created %1$s" : "Has creat %1$s",
    "%2$s created %1$s" : "%2$s ha creat %1$s",
    "%1$s was created in a public folder" : "Es va crear %1$s en una carpeta pública",
    "You changed %1$s" : "Has canviat %1$s",
    "%2$s changed %1$s" : "%2$s ha canviat %1$s",
    "You deleted %1$s" : "Has esborrat %1$s",
    "%2$s deleted %1$s" : "%2$s ha esborrat %1$s",
    "You restored %1$s" : "Has restaurat %1$s",
    "%2$s restored %1$s" : "%2$s ha restaurat %1$s",
    "Upload (max. %s)" : "Pujada (màx. %s)",
    "File handling" : "Gestió de fitxers",
    "Maximum upload size" : "Mida màxima de pujada",
    "max. possible: " : "màxim possible:",
    "Save" : "Desa",
    "Settings" : "Arranjament",
    "WebDAV" : "WebDAV",
    "No files in here" : "No hi ha arxius",
    "Upload some content or sync with your devices!" : "Pugi continguts o sincronitzi els seus dispositius.",
    "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
    "Select all" : "Seleccionar tot",
    "Upload too large" : "La pujada és massa gran",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Els fitxers que esteu intentant pujar excedeixen la mida màxima de pujada del servidor",
    "No favorites" : "No hi ha favorits",
    "Files and folders you mark as favorite will show up here" : "Aquí apareixeran els arxius i carpetes que vostè marqui com favorits",
    "Text file" : "Fitxer de text",
    "Storage is temporarily not available" : "Emmagatzematge temporalment no disponible"
},
"nplurals=2; plural=(n != 1);");
